package FBP::StaticLine;

use Mouse;

our $VERSION = '0.05';

extends 'FBP::Window';

1;
